@@ -1310,11 +1310,8 @@ css_matcher_apply_rule (HtmlDocument *document, HtmlStyle *style, HtmlStyle *par
 		case HTML_ATOM_JUSTIFY:
 			type = HTML_TEXT_ALIGN_JUSTIFY;
 			break;
-		case HTML_ATOM_BOTTOM:
-			g_warning ("text-align:bottom not supported");
-			break;
 		default:
-			g_assert_not_reached ();
+			g_message ("Unrecognized text-align attribute value");
 			break;
 		};
 		html_style_set_text_align (style, type);
